﻿-- Author      : Brandon
-- Create Date : 10/19/2008 12:05:01 PM
local L = LibStub("AceLocale-3.0"):GetLocale("SRT", true)
local LSM = LibStub("LibSharedMedia-3.0")

local SRTAddedToBlizzConfig = false
function SRT:CreateConfigMenu()
	local options = {
		name = L["Seraphim Raid Tracker"],
		handler = SRT,
		desc = L["ModDesc"],
		childGroups = "tab",
		type = 'group',
		args = {
			CurrentStats = {
				type = 'group',
				name = "Current Stats",
				order = 5,
				args = {
					RaidMembers = {
						type = 'description',
						order = 1,
						name = 'Current Raid Members',
					},
				},
			},
			GeneralOptions = {
				type = 'group',
				name = 'General Options',
				order = 10,
				args = {
					GeneralOptionsDesc = {
						type = "description",
						order = 11,
						name = "General Options",
					},					
					updateeor = {
						type = 'execute',
						order = 20,
						name = "Update EOR Points",
						desc = "Update point totals at the end of a raid.",
						func = function() SRT:ConfirmUpdateEndOfRaidPoints() end,
					},
					DebugOptionsDesc = {
						type = "description",
						order = 70,
						name = "Debug Options",
					},
					resetall = {
						type = 'execute',
						order = 80,
						name = 'Reset All Data',
						desc = 'Resets all data back to the defaults. This will reset all point counts to 0',
						func =	function()
									SRT:ResetAll()
								end,
						confirm = true,												
					},
					addguild = {
						type = "execute",
						order = 90,
						name = "Add Guild Members",
						desc = "Adds online guild members to points list",
						func =	function()
									SRT:AddGuildMembers()
								end,								
					},
					printraid = {
						type = "execute",
						order = 100,
						name = "Print Raid Members",
						desc = "Prints current raid members list. This includes all members who have been in the raid at any point in time.",
						func =	function()
									SRT:DisplayCurRaidMembers()
								end,
					},
				},
			},
			PointCounts = {
				type = 'group',
				name = 'Point Counts',
				desc = 'Allows you to view and edit the points values for all players in the database',
				order = 20,
				args = {
				},
			},
			DeletePlayers = {
				type = 'group',
				name = 'Delete Players',
				desc = 'Allows you to delete individual players from the database',
				order = 30,
				args = {
				},
			},
			Export = {
				type = 'group',
				name = 'Export',
				desc = 'Exports data into various formats',
				order = 40,
				args = {
					exportdesc = {
						order = 10,
						type = 'description',						
						name = 'Select the text in the following boxes (CTRL+A) and then copy it to the clipboard (CTRL+C) to export.',
					},
					PreEoRBBCode = {
						type = 'group',
						name = 'Pre EoR BBCode Export',
						desc = 'Exports data into BBCode format suitable for use on the fourms.',
						order = 20,
						args = {					
							exportbbcode = {
								type = 'input',
								order = 20,
								name = 'Export to BBCode',
								desc = 'Exports points list to BBCode suitable for the forums. Do this before updating End of Raid points!',
								get = function()
											return SRT:ExportPointsData("bbcode", true)
										end,
								set = function()
										end,
								multiline = true,						
							},
						},
					},
					PreEoRHTML = {
						type = 'group',
						name = 'Pre EoR HTML Export',
						desc = 'Exports Pre-End of Raid data into a HTML table',
						order = 30,
						args = {					
							exporthtml = {
								type = 'input',
								order = 30,
								name = 'Export to HTML',
								desc = 'Exports points list to a HTML table! Do this before updating End of Raid points!',
								get = function()
											return SRT:ExportPointsData("html", true)
										end,
								set = function()
										end,
								multiline = true,						
							},
						},
					},
					CurrentBBCode = {
						type = 'group',
						name = 'Current BBCode Export',
						desc = 'Exports current points list to BBCode suitable for the forums.',
						order = 40,
						args = {							
							exportbbcodecurrent = {
								type = 'input',
								order = 50,
								name = 'Export Current to BBCode',
								desc = 'Exports current points list to BBCode suitable for the forums. Do this before updating End of Raid points!',
								get = function()
											return SRT:ExportPointsData("bbcode")
										end,
								set = function()
										end,
								multiline = true,						
							},
						},
					},
					CurrentHTML = {
						type = 'group',
						name = 'Current HTML Export',
						desc = 'Exports current points list into a HTML table.',
						order = 50,
						args = {
							exporthtmlcurrent = {
								type = 'input',
								order = 60,
								name = 'Export Current to HTML',
								desc = 'Exports current points list to a HTML table! Do this before updating End of Raid points!',
								get = function()
											return SRT:ExportPointsData("html")
										end,
								set = function()
										end,
								multiline = true,						
							},
						},
					},
				},
			},			
		},			
	}
	
	if self.db.global.players then
		for i, v in ipairs(self.db.global.players) do
			if v.player and v.points then			
				--table.insert(options.args.PointCounts.args, v.player = {},
				options.args.PointCounts.args[v.player] = {	type = 'input',
																name = v.player,
																desc = '',
																get = function(info)
																			local points = SRT:GetPoints(info[#info])																		
																			return tostring(points)
																		end,
																set =	function(info, value) 																			
																			SRT:ManualSetPoints(info[#info], tonumber(value)) 
																		end, 
															}
				options.args.DeletePlayers.args[v.player] = { type = 'execute', name = v.player, desc = string.format("Deletes all data for player %s", v.player),
																func =	function(info)
																			SRT:DeletePlayerData(info[#info])
																			SRT:CreateConfigMenu()
																		end,
																confirm = true,
															}
			end
		end
	end
	
	local orderCount = 2
	
	for i,v in ipairs(self.db.global.raidMembers) do
		if v then 
			local data = SRT:GetPlayerData(v)
			options.args.CurrentStats.args[v] = { type = 'description', order = orderCount, name = string.format("%s | Rank: %s | Points: %d", v, data.guildRank, data.points), }
			orderCount = orderCount + 1
		end
	end
	options.args.CurrentStats.args["Spacer1"] = { type = 'description', order = orderCount, name = '', }
	orderCount = orderCount + 1
	options.args.CurrentStats.args["ShardCount"] = { type = 'description', order = orderCount, name = string.format("Shard Count: %d", self.db.global.shardCount), }
	orderCount = orderCount + 1
	options.args.CurrentStats.args["OffsetCount"] = { type = 'description', order = orderCount, name = string.format("Offset Count: %d", self.db.global.offsetCount), }
	orderCount = orderCount + 1
	options.args.CurrentStats.args["LootCount"] = { type = 'description', order = orderCount, name = string.format("Upgrade Count: %d", self.db.global.lootCount), }
	orderCount = orderCount + 1
	
	options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("SRTConfig", options, {"srt", "srtconfig"})	
	
	if SRTAddedToBlizzConfig == false then
		LibStub("AceConfigDialog-3.0"):AddToBlizOptions("SRTConfig", L["Seraphim Raid Tracker"])	
		SRTAddedToBlizzConfig = true
	end

end


